==> mkdocstrings_github-0.6.3.tar.gz: mkdocstrings_github-0.6.3/docs/changelog.md <==
# CHANGELOG

<!-- version list -->

## v0.6.3 (2025-12-09)

### Bug Fixes

- Multiline comments ([#46](https://github.com/watermarkhu/mkdocstrings-github/pull/46),
  [`3787e44`](https://github.com/watermarkhu/mkdocstrings-github/commit/3787e4437bd879ae779ff4d128827ed407385131))


## v0.6.2 (2025-11-30)

### Chores

- **deps**: Update group-pyproject
  ([#45](https://github.com/watermarkhu/mkdocstrings-github/pull/45),
  [`5b13468`](https://github.com/watermarkhu/mkdocstrings-github/commit/5b1346847e9e9347ee8d9cbd84d62d23c1c82223))

- **deps**: Update group-pyproject (major)
  ([#45](https://github.com/watermarkhu/mkdocstrings-github/pull/45),
  [`5b13468`](https://github.com/watermarkhu/mkdocstrings-github/commit/5b1346847e9e9347ee8d9cbd84d62d23c1c82223))

### Continuous Integration

- **deps**: Update actions/checkout action to v6
  ([#44](https://github.com/watermarkhu/mkdocstrings-github/pull/44),
  [`738ef72`](https://github.com/watermarkhu/mkdocstrings-github/commit/738ef727a737de1851fb4ecd556f5f4cf6c6d667))


## v0.6.1 (2025-11-10)

### Build System

- **deps**: Update dependency inline-snapshot to ~=0.31.0
  ([#38](https://github.com/watermarkhu/mkdocstrings-github/pull/38),
  [`df160a0`](https://github.com/watermarkhu/mkdocstrings-github/commit/df160a0f10f19d0ac589d2a4e13d9260d4b93fe0))

- **deps**: Update dependency pytest to v9
  ([#40](https://github.com/watermarkhu/mkdocstrings-github/pull/40),
  [`f338dbc`](https://github.com/watermarkhu/mkdocstrings-github/commit/f338dbcbf70dd89a1559ead510896816a0ed1ce0))

- **deps**: Update dependency python-semantic-release to ~=10.5.0
  ([#41](https://github.com/watermarkhu/mkdocstrings-github/pull/41),
  [`e1a78c7`](https://github.com/watermarkhu/mkdocstrings-github/commit/e1a78c753faa67b937737fc22e4826ba609bcc70))

### Chores

- **deps**: Update dependency mkdocstrings-python to ~=1.19.0
  ([#42](https://github.com/watermarkhu/mkdocstrings-github/pull/42),
  [`7f92d5d`](https://github.com/watermarkhu/mkdocstrings-github/commit/7f92d5d0613007a7f1cc0cde76ba2159d8f30efd))

### Testing

- Fix test_get_repository_name_no_remotes for CI environment
  ([#39](https://github.com/watermarkhu/mkdocstrings-github/pull/39),
  [`a04e7c7`](https://github.com/watermarkhu/mkdocstrings-github/commit/a04e7c78b7b2caf91b48f8d257b84c3e3e549bf3))

- Improve test coverage to 99% ([#39](https://github.com/watermarkhu/mkdocstrings-github/pull/39),
  [`a04e7c7`](https://github.com/watermarkhu/mkdocstrings-github/commit/a04e7c78b7b2caf91b48f8d257b84c3e3e549bf3))


## v0.6.0 (2025-10-27)

### Build System

- **deps**: Update dependency inline-snapshot to ~=0.30.0
  ([#35](https://github.com/watermarkhu/mkdocstrings-github/pull/35),
  [`8e8214d`](https://github.com/watermarkhu/mkdocstrings-github/commit/8e8214d31f875a2921fa007248153e71179d0407))

### Continuous Integration

- **deps**: Update group-github-actions
  ([#36](https://github.com/watermarkhu/mkdocstrings-github/pull/36),
  [`1e13659`](https://github.com/watermarkhu/mkdocstrings-github/commit/1e13659585994c534f817e76bd530ec96e134bc3))

- **deps**: Update group-github-actions (major)
  ([#36](https://github.com/watermarkhu/mkdocstrings-github/pull/36),
  [`1e13659`](https://github.com/watermarkhu/mkdocstrings-github/commit/1e13659585994c534f817e76bd530ec96e134bc3))

### Features

- Add parameter grouping, ruamel.yaml
  ([#37](https://github.com/watermarkhu/mkdocstrings-github/pull/37),
  [`c6d8681`](https://github.com/watermarkhu/mkdocstrings-github/commit/c6d8681281adefe935f6abfb009257301fc6537f))


## v0.5.1 (2025-10-14)

### Bug Fixes

- Do not validate signature_repository
  ([#34](https://github.com/watermarkhu/mkdocstrings-github/pull/34),
  [`3ead525`](https://github.com/watermarkhu/mkdocstrings-github/commit/3ead5253eb68e9a5fb5def55e807801afc1ef106))


## v0.5.0 (2025-10-13)

### Bug Fixes

- Properly show read-all/write-all permissions
  ([#33](https://github.com/watermarkhu/mkdocstrings-github/pull/33),
  [`5f5e792`](https://github.com/watermarkhu/mkdocstrings-github/commit/5f5e7921fd326bbcdec903101107c6128dab5dbf))

### Documentation

- Better docs with actions/checkout example
  ([#33](https://github.com/watermarkhu/mkdocstrings-github/pull/33),
  [`5f5e792`](https://github.com/watermarkhu/mkdocstrings-github/commit/5f5e7921fd326bbcdec903101107c6128dab5dbf))

### Features

- Move signature repository name to local options
  ([#33](https://github.com/watermarkhu/mkdocstrings-github/pull/33),
  [`5f5e792`](https://github.com/watermarkhu/mkdocstrings-github/commit/5f5e7921fd326bbcdec903101107c6128dab5dbf))


## v0.4.5 (2025-10-13)

### Refactoring

- Show annotation in stead of empty
  ([#32](https://github.com/watermarkhu/mkdocstrings-github/pull/32),
  [`46942af`](https://github.com/watermarkhu/mkdocstrings-github/commit/46942af6c6c2794830738749909edd39ea2ca204))

- Show annotation instead of empty
  ([#32](https://github.com/watermarkhu/mkdocstrings-github/pull/32),
  [`46942af`](https://github.com/watermarkhu/mkdocstrings-github/commit/46942af6c6c2794830738749909edd39ea2ca204))


## v0.4.4 (2025-10-13)

### Bug Fixes

- **templates**: Hide signature sections properly
  ([#31](https://github.com/watermarkhu/mkdocstrings-github/pull/31),
  [`86d9628`](https://github.com/watermarkhu/mkdocstrings-github/commit/86d9628770ab235280ffc65434009355946b7d0c))


## v0.4.3 (2025-10-12)

### Bug Fixes

- Hide secrets and inputs from signature if there are none
  ([#30](https://github.com/watermarkhu/mkdocstrings-github/pull/30),
  [`f9831f6`](https://github.com/watermarkhu/mkdocstrings-github/commit/f9831f648b8eeed287f35843a1d15c7f845c1bb0))

### Continuous Integration

- More tests ([#30](https://github.com/watermarkhu/mkdocstrings-github/pull/30),
  [`f9831f6`](https://github.com/watermarkhu/mkdocstrings-github/commit/f9831f648b8eeed287f35843a1d15c7f845c1bb0))

### Performance Improvements

- Use GITHUB_REPOSITORY env var in GitHub Actions
  ([#30](https://github.com/watermarkhu/mkdocstrings-github/pull/30),
  [`f9831f6`](https://github.com/watermarkhu/mkdocstrings-github/commit/f9831f648b8eeed287f35843a1d15c7f845c1bb0))


## v0.4.2 (2025-10-08)

### Bug Fixes

- Better package tag ordering ([#28](https://github.com/watermarkhu/mkdocstrings-github/pull/28),
  [`10dc87a`](https://github.com/watermarkhu/mkdocstrings-github/commit/10dc87a001908af6522320a5248ce4c988e441a3))


## v0.4.1 (2025-10-08)

### Bug Fixes

- Tag ordering ([#27](https://github.com/watermarkhu/mkdocstrings-github/pull/27),
  [`76256f5`](https://github.com/watermarkhu/mkdocstrings-github/commit/76256f52bbd53be825ba0a0576d7cb6a6da54d3a))

### Documentation

- Update docs ([#26](https://github.com/watermarkhu/mkdocstrings-github/pull/26),
  [`96f650f`](https://github.com/watermarkhu/mkdocstrings-github/commit/96f650f1d4af5b5d6da4704e7b2184e4016f3a39))


## v0.4.0 (2025-10-08)

### Continuous Integration

- **deps**: Update actions/checkout action to v5
  ([#22](https://github.com/watermarkhu/mkdocstrings-github/pull/22),
  [`fc56971`](https://github.com/watermarkhu/mkdocstrings-github/commit/fc569719b4387f11119de588d2f67f1daa09c233))

- **deps**: Update astral-sh/setup-uv action to v7
  ([#24](https://github.com/watermarkhu/mkdocstrings-github/pull/24),
  [`a07de53`](https://github.com/watermarkhu/mkdocstrings-github/commit/a07de53b318859a365215730c2c09d0d5fdcf5b1))

### Features

- Get releases using tags ([#25](https://github.com/watermarkhu/mkdocstrings-github/pull/25),
  [`25ea11d`](https://github.com/watermarkhu/mkdocstrings-github/commit/25ea11d8c0f92a1e49f8b35b60456259e4e0ec7b))


## v0.3.0 (2025-10-07)

### Bug Fixes

- Prek configuration with local uv
  ([#20](https://github.com/watermarkhu/mkdocstrings-github/pull/20),
  [`0d53c40`](https://github.com/watermarkhu/mkdocstrings-github/commit/0d53c4029fc0f2e30f4f223b6d81221236254832))

### Build System

- **deps**: Update dependency ruff to ~=0.14.0
  ([#21](https://github.com/watermarkhu/mkdocstrings-github/pull/21),
  [`f87cf24`](https://github.com/watermarkhu/mkdocstrings-github/commit/f87cf2485121f4056279ce06ed721e02fc475f1b))

### Continuous Integration

- Add codecov ([#20](https://github.com/watermarkhu/mkdocstrings-github/pull/20),
  [`0d53c40`](https://github.com/watermarkhu/mkdocstrings-github/commit/0d53c4029fc0f2e30f4f223b6d81221236254832))

- **deps**: Update peter-evans/create-or-update-comment action to v5
  ([#19](https://github.com/watermarkhu/mkdocstrings-github/pull/19),
  [`8135a2b`](https://github.com/watermarkhu/mkdocstrings-github/commit/8135a2bff69a41bde0676b991145ff089563bf7b))

### Features

- Hide default and section if non are available
  ([#20](https://github.com/watermarkhu/mkdocstrings-github/pull/20),
  [`0d53c40`](https://github.com/watermarkhu/mkdocstrings-github/commit/0d53c4029fc0f2e30f4f223b6d81221236254832))

- Hide default and section if non are available.
  ([#20](https://github.com/watermarkhu/mkdocstrings-github/pull/20),
  [`0d53c40`](https://github.com/watermarkhu/mkdocstrings-github/commit/0d53c4029fc0f2e30f4f223b6d81221236254832))


## v0.2.6 (2025-10-02)

### Bug Fixes

- Empty workflow_call ([#18](https://github.com/watermarkhu/mkdocstrings-github/pull/18),
  [`368b9b5`](https://github.com/watermarkhu/mkdocstrings-github/commit/368b9b5097d6d0c061cb9addbfc9fc721a16dea7))

### Continuous Integration

- **deps**: Update peter-evans/find-comment action to v4
  ([#17](https://github.com/watermarkhu/mkdocstrings-github/pull/17),
  [`8e2375d`](https://github.com/watermarkhu/mkdocstrings-github/commit/8e2375d1df0a9883c9a365dfc5b2563997fb1f70))


## v0.2.5 (2025-09-29)

### Bug Fixes

- No repo set ([#16](https://github.com/watermarkhu/mkdocstrings-github/pull/16),
  [`554d230`](https://github.com/watermarkhu/mkdocstrings-github/commit/554d230a3c8da0bee86a2c8b2805c873852d6bfd))

### Documentation

- Small fix ([#15](https://github.com/watermarkhu/mkdocstrings-github/pull/15),
  [`22c6693`](https://github.com/watermarkhu/mkdocstrings-github/commit/22c669395cce94b315ab08434fdc4e7ba167f7a5))


## v0.2.4 (2025-09-29)

### Bug Fixes

- Allow setting hostname ([#14](https://github.com/watermarkhu/mkdocstrings-github/pull/14),
  [`4676e57`](https://github.com/watermarkhu/mkdocstrings-github/commit/4676e57cda03b8a52ae6facf4a28f3dde9adb365))

- Set hostname ([#14](https://github.com/watermarkhu/mkdocstrings-github/pull/14),
  [`4676e57`](https://github.com/watermarkhu/mkdocstrings-github/commit/4676e57cda03b8a52ae6facf4a28f3dde9adb365))


## v0.2.3 (2025-09-29)

### Bug Fixes

- Default host ([#13](https://github.com/watermarkhu/mkdocstrings-github/pull/13),
  [`8ac9b06`](https://github.com/watermarkhu/mkdocstrings-github/commit/8ac9b062e53b47e27cc1adad6c206087d8a7da1a))


## v0.2.2 (2025-09-29)

### Bug Fixes

- Get GH_TOKEN ([#12](https://github.com/watermarkhu/mkdocstrings-github/pull/12),
  [`3c449ea`](https://github.com/watermarkhu/mkdocstrings-github/commit/3c449ea0bfeaac96667d7d31b668d25921279bd6))


## v0.2.1 (2025-09-29)

### Bug Fixes

- GitHub Enterprise with GH_HOST ([#11](https://github.com/watermarkhu/mkdocstrings-github/pull/11),
  [`4f59dc0`](https://github.com/watermarkhu/mkdocstrings-github/commit/4f59dc07eb1f564d31431e4f3bf2e6fb1bcdfeb6))

### Documentation

- Update docs ([#10](https://github.com/watermarkhu/mkdocstrings-github/pull/10),
  [`3be05f5`](https://github.com/watermarkhu/mkdocstrings-github/commit/3be05f57605fbf12ab9c1ea8583775e1e47b25f2))


## v0.2.0 (2025-09-28)

### Features

- Cross-linking ([#9](https://github.com/watermarkhu/mkdocstrings-github/pull/9),
  [`6bcf229`](https://github.com/watermarkhu/mkdocstrings-github/commit/6bcf229ad97702a44ba68ceb135ffd4b53208339))


## v0.1.0 (2025-09-28)

- Initial Release

==> mkdocstrings_github-0.6.4.tar.gz: mkdocstrings_github-0.6.4/docs/changelog.md <==
# CHANGELOG

<!-- version list -->

## v0.6.4 (2026-01-13)

### Chores

- **deps**: Update dependency griffe-pydantic to ~=1.2.0
  ([#48](https://github.com/watermarkhu/mkdocstrings-github/pull/48),
  [`d50a817`](https://github.com/watermarkhu/mkdocstrings-github/commit/d50a81740e863fc4f7a620877b75e1a314a39e79))

### Continuous Integration

- **deps**: Update group-github-actions
  ([#47](https://github.com/watermarkhu/mkdocstrings-github/pull/47),
  [`cdc464d`](https://github.com/watermarkhu/mkdocstrings-github/commit/cdc464db951c635626a5af6da9ccd7c300012e60))

- **deps**: Update group-github-actions (major)
  ([#47](https://github.com/watermarkhu/mkdocstrings-github/pull/47),
  [`cdc464d`](https://github.com/watermarkhu/mkdocstrings-github/commit/cdc464db951c635626a5af6da9ccd7c300012e60))


## v0.6.3 (2025-12-09)

### Bug Fixes

- Multiline comments ([#46](https://github.com/watermarkhu/mkdocstrings-github/pull/46),
  [`3787e44`](https://github.com/watermarkhu/mkdocstrings-github/commit/3787e4437bd879ae779ff4d128827ed407385131))


## v0.6.2 (2025-11-30)

### Chores

- **deps**: Update group-pyproject
  ([#45](https://github.com/watermarkhu/mkdocstrings-github/pull/45),
  [`5b13468`](https://github.com/watermarkhu/mkdocstrings-github/commit/5b1346847e9e9347ee8d9cbd84d62d23c1c82223))

- **deps**: Update group-pyproject (major)
  ([#45](https://github.com/watermarkhu/mkdocstrings-github/pull/45),
  [`5b13468`](https://github.com/watermarkhu/mkdocstrings-github/commit/5b1346847e9e9347ee8d9cbd84d62d23c1c82223))

### Continuous Integration

- **deps**: Update actions/checkout action to v6
  ([#44](https://github.com/watermarkhu/mkdocstrings-github/pull/44),
  [`738ef72`](https://github.com/watermarkhu/mkdocstrings-github/commit/738ef727a737de1851fb4ecd556f5f4cf6c6d667))


## v0.6.1 (2025-11-10)

### Build System

- **deps**: Update dependency inline-snapshot to ~=0.31.0
  ([#38](https://github.com/watermarkhu/mkdocstrings-github/pull/38),
  [`df160a0`](https://github.com/watermarkhu/mkdocstrings-github/commit/df160a0f10f19d0ac589d2a4e13d9260d4b93fe0))

- **deps**: Update dependency pytest to v9
  ([#40](https://github.com/watermarkhu/mkdocstrings-github/pull/40),
  [`f338dbc`](https://github.com/watermarkhu/mkdocstrings-github/commit/f338dbcbf70dd89a1559ead510896816a0ed1ce0))

- **deps**: Update dependency python-semantic-release to ~=10.5.0
  ([#41](https://github.com/watermarkhu/mkdocstrings-github/pull/41),
  [`e1a78c7`](https://github.com/watermarkhu/mkdocstrings-github/commit/e1a78c753faa67b937737fc22e4826ba609bcc70))

### Chores

- **deps**: Update dependency mkdocstrings-python to ~=1.19.0
  ([#42](https://github.com/watermarkhu/mkdocstrings-github/pull/42),
  [`7f92d5d`](https://github.com/watermarkhu/mkdocstrings-github/commit/7f92d5d0613007a7f1cc0cde76ba2159d8f30efd))

### Testing

- Fix test_get_repository_name_no_remotes for CI environment
  ([#39](https://github.com/watermarkhu/mkdocstrings-github/pull/39),
  [`a04e7c7`](https://github.com/watermarkhu/mkdocstrings-github/commit/a04e7c78b7b2caf91b48f8d257b84c3e3e549bf3))

- Improve test coverage to 99% ([#39](https://github.com/watermarkhu/mkdocstrings-github/pull/39),
  [`a04e7c7`](https://github.com/watermarkhu/mkdocstrings-github/commit/a04e7c78b7b2caf91b48f8d257b84c3e3e549bf3))


## v0.6.0 (2025-10-27)

### Build System

- **deps**: Update dependency inline-snapshot to ~=0.30.0
  ([#35](https://github.com/watermarkhu/mkdocstrings-github/pull/35),
  [`8e8214d`](https://github.com/watermarkhu/mkdocstrings-github/commit/8e8214d31f875a2921fa007248153e71179d0407))

### Continuous Integration

- **deps**: Update group-github-actions
  ([#36](https://github.com/watermarkhu/mkdocstrings-github/pull/36),
  [`1e13659`](https://github.com/watermarkhu/mkdocstrings-github/commit/1e13659585994c534f817e76bd530ec96e134bc3))

- **deps**: Update group-github-actions (major)
  ([#36](https://github.com/watermarkhu/mkdocstrings-github/pull/36),
  [`1e13659`](https://github.com/watermarkhu/mkdocstrings-github/commit/1e13659585994c534f817e76bd530ec96e134bc3))

### Features

- Add parameter grouping, ruamel.yaml
  ([#37](https://github.com/watermarkhu/mkdocstrings-github/pull/37),
  [`c6d8681`](https://github.com/watermarkhu/mkdocstrings-github/commit/c6d8681281adefe935f6abfb009257301fc6537f))


## v0.5.1 (2025-10-14)

### Bug Fixes

- Do not validate signature_repository
  ([#34](https://github.com/watermarkhu/mkdocstrings-github/pull/34),
  [`3ead525`](https://github.com/watermarkhu/mkdocstrings-github/commit/3ead5253eb68e9a5fb5def55e807801afc1ef106))


## v0.5.0 (2025-10-13)

### Bug Fixes

- Properly show read-all/write-all permissions
  ([#33](https://github.com/watermarkhu/mkdocstrings-github/pull/33),
  [`5f5e792`](https://github.com/watermarkhu/mkdocstrings-github/commit/5f5e7921fd326bbcdec903101107c6128dab5dbf))

### Documentation

- Better docs with actions/checkout example
  ([#33](https://github.com/watermarkhu/mkdocstrings-github/pull/33),
  [`5f5e792`](https://github.com/watermarkhu/mkdocstrings-github/commit/5f5e7921fd326bbcdec903101107c6128dab5dbf))

### Features

- Move signature repository name to local options
  ([#33](https://github.com/watermarkhu/mkdocstrings-github/pull/33),
  [`5f5e792`](https://github.com/watermarkhu/mkdocstrings-github/commit/5f5e7921fd326bbcdec903101107c6128dab5dbf))


## v0.4.5 (2025-10-13)

### Refactoring

- Show annotation in stead of empty
  ([#32](https://github.com/watermarkhu/mkdocstrings-github/pull/32),
  [`46942af`](https://github.com/watermarkhu/mkdocstrings-github/commit/46942af6c6c2794830738749909edd39ea2ca204))

- Show annotation instead of empty
  ([#32](https://github.com/watermarkhu/mkdocstrings-github/pull/32),
  [`46942af`](https://github.com/watermarkhu/mkdocstrings-github/commit/46942af6c6c2794830738749909edd39ea2ca204))


## v0.4.4 (2025-10-13)

### Bug Fixes

- **templates**: Hide signature sections properly
  ([#31](https://github.com/watermarkhu/mkdocstrings-github/pull/31),
  [`86d9628`](https://github.com/watermarkhu/mkdocstrings-github/commit/86d9628770ab235280ffc65434009355946b7d0c))


## v0.4.3 (2025-10-12)

### Bug Fixes

- Hide secrets and inputs from signature if there are none
  ([#30](https://github.com/watermarkhu/mkdocstrings-github/pull/30),
  [`f9831f6`](https://github.com/watermarkhu/mkdocstrings-github/commit/f9831f648b8eeed287f35843a1d15c7f845c1bb0))

### Continuous Integration

- More tests ([#30](https://github.com/watermarkhu/mkdocstrings-github/pull/30),
  [`f9831f6`](https://github.com/watermarkhu/mkdocstrings-github/commit/f9831f648b8eeed287f35843a1d15c7f845c1bb0))

### Performance Improvements

- Use GITHUB_REPOSITORY env var in GitHub Actions
  ([#30](https://github.com/watermarkhu/mkdocstrings-github/pull/30),
  [`f9831f6`](https://github.com/watermarkhu/mkdocstrings-github/commit/f9831f648b8eeed287f35843a1d15c7f845c1bb0))


## v0.4.2 (2025-10-08)

### Bug Fixes

- Better package tag ordering ([#28](https://github.com/watermarkhu/mkdocstrings-github/pull/28),
  [`10dc87a`](https://github.com/watermarkhu/mkdocstrings-github/commit/10dc87a001908af6522320a5248ce4c988e441a3))


## v0.4.1 (2025-10-08)

### Bug Fixes

- Tag ordering ([#27](https://github.com/watermarkhu/mkdocstrings-github/pull/27),
  [`76256f5`](https://github.com/watermarkhu/mkdocstrings-github/commit/76256f52bbd53be825ba0a0576d7cb6a6da54d3a))

### Documentation

- Update docs ([#26](https://github.com/watermarkhu/mkdocstrings-github/pull/26),
  [`96f650f`](https://github.com/watermarkhu/mkdocstrings-github/commit/96f650f1d4af5b5d6da4704e7b2184e4016f3a39))


## v0.4.0 (2025-10-08)

### Continuous Integration

- **deps**: Update actions/checkout action to v5
  ([#22](https://github.com/watermarkhu/mkdocstrings-github/pull/22),
  [`fc56971`](https://github.com/watermarkhu/mkdocstrings-github/commit/fc569719b4387f11119de588d2f67f1daa09c233))

- **deps**: Update astral-sh/setup-uv action to v7
  ([#24](https://github.com/watermarkhu/mkdocstrings-github/pull/24),
  [`a07de53`](https://github.com/watermarkhu/mkdocstrings-github/commit/a07de53b318859a365215730c2c09d0d5fdcf5b1))

### Features

- Get releases using tags ([#25](https://github.com/watermarkhu/mkdocstrings-github/pull/25),
  [`25ea11d`](https://github.com/watermarkhu/mkdocstrings-github/commit/25ea11d8c0f92a1e49f8b35b60456259e4e0ec7b))


## v0.3.0 (2025-10-07)

### Bug Fixes

- Prek configuration with local uv
  ([#20](https://github.com/watermarkhu/mkdocstrings-github/pull/20),
  [`0d53c40`](https://github.com/watermarkhu/mkdocstrings-github/commit/0d53c4029fc0f2e30f4f223b6d81221236254832))

### Build System

- **deps**: Update dependency ruff to ~=0.14.0
  ([#21](https://github.com/watermarkhu/mkdocstrings-github/pull/21),
  [`f87cf24`](https://github.com/watermarkhu/mkdocstrings-github/commit/f87cf2485121f4056279ce06ed721e02fc475f1b))

### Continuous Integration

- Add codecov ([#20](https://github.com/watermarkhu/mkdocstrings-github/pull/20),
  [`0d53c40`](https://github.com/watermarkhu/mkdocstrings-github/commit/0d53c4029fc0f2e30f4f223b6d81221236254832))

- **deps**: Update peter-evans/create-or-update-comment action to v5
  ([#19](https://github.com/watermarkhu/mkdocstrings-github/pull/19),
  [`8135a2b`](https://github.com/watermarkhu/mkdocstrings-github/commit/8135a2bff69a41bde0676b991145ff089563bf7b))

### Features

- Hide default and section if non are available
  ([#20](https://github.com/watermarkhu/mkdocstrings-github/pull/20),
  [`0d53c40`](https://github.com/watermarkhu/mkdocstrings-github/commit/0d53c4029fc0f2e30f4f223b6d81221236254832))

- Hide default and section if non are available.
  ([#20](https://github.com/watermarkhu/mkdocstrings-github/pull/20),
  [`0d53c40`](https://github.com/watermarkhu/mkdocstrings-github/commit/0d53c4029fc0f2e30f4f223b6d81221236254832))


## v0.2.6 (2025-10-02)

### Bug Fixes

- Empty workflow_call ([#18](https://github.com/watermarkhu/mkdocstrings-github/pull/18),
  [`368b9b5`](https://github.com/watermarkhu/mkdocstrings-github/commit/368b9b5097d6d0c061cb9addbfc9fc721a16dea7))

### Continuous Integration

- **deps**: Update peter-evans/find-comment action to v4
  ([#17](https://github.com/watermarkhu/mkdocstrings-github/pull/17),
  [`8e2375d`](https://github.com/watermarkhu/mkdocstrings-github/commit/8e2375d1df0a9883c9a365dfc5b2563997fb1f70))


## v0.2.5 (2025-09-29)

### Bug Fixes

- No repo set ([#16](https://github.com/watermarkhu/mkdocstrings-github/pull/16),
  [`554d230`](https://github.com/watermarkhu/mkdocstrings-github/commit/554d230a3c8da0bee86a2c8b2805c873852d6bfd))

### Documentation

- Small fix ([#15](https://github.com/watermarkhu/mkdocstrings-github/pull/15),
  [`22c6693`](https://github.com/watermarkhu/mkdocstrings-github/commit/22c669395cce94b315ab08434fdc4e7ba167f7a5))


## v0.2.4 (2025-09-29)

### Bug Fixes

- Allow setting hostname ([#14](https://github.com/watermarkhu/mkdocstrings-github/pull/14),
  [`4676e57`](https://github.com/watermarkhu/mkdocstrings-github/commit/4676e57cda03b8a52ae6facf4a28f3dde9adb365))

- Set hostname ([#14](https://github.com/watermarkhu/mkdocstrings-github/pull/14),
  [`4676e57`](https://github.com/watermarkhu/mkdocstrings-github/commit/4676e57cda03b8a52ae6facf4a28f3dde9adb365))


## v0.2.3 (2025-09-29)

### Bug Fixes

- Default host ([#13](https://github.com/watermarkhu/mkdocstrings-github/pull/13),
  [`8ac9b06`](https://github.com/watermarkhu/mkdocstrings-github/commit/8ac9b062e53b47e27cc1adad6c206087d8a7da1a))


## v0.2.2 (2025-09-29)

### Bug Fixes

- Get GH_TOKEN ([#12](https://github.com/watermarkhu/mkdocstrings-github/pull/12),
  [`3c449ea`](https://github.com/watermarkhu/mkdocstrings-github/commit/3c449ea0bfeaac96667d7d31b668d25921279bd6))


## v0.2.1 (2025-09-29)

### Bug Fixes

- GitHub Enterprise with GH_HOST ([#11](https://github.com/watermarkhu/mkdocstrings-github/pull/11),
  [`4f59dc0`](https://github.com/watermarkhu/mkdocstrings-github/commit/4f59dc07eb1f564d31431e4f3bf2e6fb1bcdfeb6))

### Documentation

- Update docs ([#10](https://github.com/watermarkhu/mkdocstrings-github/pull/10),
  [`3be05f5`](https://github.com/watermarkhu/mkdocstrings-github/commit/3be05f57605fbf12ab9c1ea8583775e1e47b25f2))


## v0.2.0 (2025-09-28)

### Features

- Cross-linking ([#9](https://github.com/watermarkhu/mkdocstrings-github/pull/9),
  [`6bcf229`](https://github.com/watermarkhu/mkdocstrings-github/commit/6bcf229ad97702a44ba68ceb135ffd4b53208339))


## v0.1.0 (2025-09-28)

- Initial Release
